local PetBattleTeams = LibStub("AceAddon-3.0"):GetAddon("PetBattleTeams")
local Config = PetBattleTeams:NewModule("Config","AceConsole-3.0")
local TeamManager = PetBattleTeams:GetModule("TeamManager")
local GUI = PetBattleTeams:GetModule("GUI")
local Tooltip = PetBattleTeams:GetModule("Tooltip")
local _

local options = {
    name = "PetBattle Teams",
    handler = self,
    type = 'group',
    args = {
			TeamFrameHeading = {
				order = 0,
				name = "Teams and Pets",
				width = "double",
				type = "header",
			},
			showXpInLevel = {
				order = 1,
				name = "Display pets xp as part of the pets level",
				width = "double",
				type = "toggle",
				set = function(info,val) 
					TeamManager:SetShowXpInLevel(val)
				end,
				get = function(info) return TeamManager:GetShowXpInLevel() end
			},
			showXpInHealth = {
				order = 2,
				name = "Display pets xp instead of the health bar ",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					TeamManager:SetShowXpInHealthBar(val)
				end,
				get = function(info) return TeamManager:GetShowXpInHealthBar() end
			},
			ShowTeamName = {
				order = 3,
				name = "Display team name above the team",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					TeamManager:SetShowTeamName(val)
				end,
				get = function(info) return TeamManager:GetShowTeamName()  end
			},
			MainFrameHeading = {
				order = 50,
				name = "Main",
				width = "double",
				type = "header",
				
			},
			AttachToPetJournal = {
				order = 51,
				name = "Attach PetBattle Teams to Pet Journal",
				desc = "When attached, PetBattle Teams will only be usable from the Pet Journal.",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					GUI:SetAttached(val)
				end,
				get = function(info) return GUI:GetAttached() end
			},
			HideInCombat = {
				order = 52,
				name = "Hide PetBattle Teams while in combat or in a Pet Battle",
				desc = "Hides PetBattle Teams while in combat or in a Pet Battle.",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					GUI:SetHideInCombat(val)
				end,
				get = function(info) return GUI:GetHideInCombat() end
			},
			LockPosition = {
				order = 52,
				name = "Lock PetBattle Teams Position",
				type = "toggle",
				width = "double",
				desc = "When the team frame is not attached to the Pet Journal then if the frame is locked it cannot be moved.",
				set = function(info,val) 
					GUI:SetLocked(val)
				end,
				get = function(info) return GUI:GetLocked() end
			},
			TooltipHeading = {
				order = 75,
				name = "Tooltip",
				width = "double",
				type = "header",
				
			},
			ShowHelperText = {
				order = 80,
				name = "Show keybinding helper text in tooltip",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					Tooltip:SetShowHelpText(val)
				end,
				get = function(info) return Tooltip:GetShowHelpText() end
			},
			
			TeamFunctionsHeading = {
				order = 100,
				name = "Team Management",
				width = "double",
				type = "header",
				
			},
			SaveTeams = {
				order = 101,
				name = "Automatically Save Teams",
				desc = "When enabled:|nThe currently selected team will have its pets updated to match the pet journal at all times unless the selected team is locked.|n|nNewly created teams will be created using the currently selected pets.",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					TeamManager:SetAutomaticallySaveTeams(val)
				end,
				get = function(info) return TeamManager:GetAutomaticallySaveTeams() end
			},
			DismissPet = {
				order = 101,
				name = "Automatically Dismiss pet after team changes",
				desc = "When enabled, Your active pet will be dismissed when switching teams",
				type = "toggle",
				width = "double",
				set = function(info,val) 
					TeamManager:SetDismissPet(val)
				end,
				get = function(info) return TeamManager:GetDismissPet(val) end
			},
			
			UnlockTeams = {
				order = 103,
				name = "Unlock all existing teams",
				width = "double",
				type = "execute",
				desc = "This does not prevent you from locking individual teams.",
				func = function() 
					TeamManager:SetLockStateAllTeams(false)
				end,
			},
			LockAllTeams = {
				order = 103,
				name = "Lock all existing teams",
				width = "double",
				type = "execute",
				desc = "This does not lock newly created teams or prevent you from unlocking individual teams.",
				func = function() 
					TeamManager:SetLockStateAllTeams(true)
					print("PetBattle Teams: All existing teams locked")
				end,
				
			},
			ResetTeams = {
				order = 110,
				name = "Delete all teams",
				type = "execute",
				width = "double",
				desc= "Permanently deletes all teams. There is no confirmation for this action.",
				func = function() 
					TeamManager:ResetTeams()
				end,
			},
			
			ResetUI = {
				order = 120,
				name = "Reset UI",
				type = "execute",
				width = "double",
				desc= "Resets the UI to its default settings. There is no confirmation for this action.",
				func = function() 
					GUI:ResetUI()
					TeamManager:ResetUI()
				end,
			},
		},
}

function Config:OnInitialize()
	LibStub("AceConfig-3.0"):RegisterOptionsTable("PetBattleTeams", options,"/pbt")
    LibStub("AceConfigDialog-3.0"):AddToBlizOptions("PetBattleTeams","PetBattle Teams")
end


